pub enum CursorIcon {
Show 35 variants
Default,
None,
ContextMenu,
Help,
PointingHand,
Progress,
Wait,
Cell,
Crosshair,
Text,
VerticalText,
Alias,
Copy,
Move,
NoDrop,
NotAllowed,
Grab,
Grabbing,
AllScroll,
ResizeHorizontal,
ResizeNeSw,
ResizeNwSe,
ResizeVertical,
ZoomIn,
ZoomOut,
ResizeEast,
ResizeSouthEast,
ResizeSouth,
ResizeSouthWest,
ResizeWest,
ResizeNorthWest,
ResizeNorth,
ResizeNorthEast,
ResizeColumn,
ResizeRow,
}Expand description
Represent mouse cursor icon They are same as egui::CursorIcon because this is mostly to give support to egui
Variants
Default
None
ContextMenu
Help
PointingHand
Progress
Wait
Cell
Crosshair
Text
VerticalText
Alias
Copy
Move
NoDrop
NotAllowed
Grab
Grabbing
AllScroll
ResizeHorizontal
ResizeNeSw
ResizeNwSe
ResizeVertical
ZoomIn
ZoomOut
ResizeEast
ResizeSouthEast
ResizeSouth
ResizeSouthWest
ResizeWest
ResizeNorthWest
ResizeNorth
ResizeNorthEast
ResizeColumn
ResizeRow