Color

Struct Color 

pub struct Color {
    pub r: f32,
    pub g: f32,
    pub b: f32,
    pub a: f32,
}
Represents a visual color

Fields

r: f32

Red value

g: f32

Green value

b: f32

Blue value

a: f32

Alpha value

Implementations

Source

impl Color

pub const TRANSPARENT: Color

pub const WHITE: Color

pub const BLACK: Color

pub const RED: Color

pub const GREEN: Color

pub const BLUE: Color

pub const YELLOW: Color

pub const MAGENTA: Color

pub const SILVER: Color

pub const GRAY: Color

pub const OLIVE: Color

pub const PURPLE: Color

pub const MAROON: Color

pub const BROWN: Color

pub const SADDLE_BROWN: Color

pub const AQUA: Color

pub const TEAL: Color

pub const NAVY: Color

pub const ORANGE: Color

pub const PINK: Color

pub const fn new(r: f32, g: f32, b: f32, a: f32) -> Color

Create a new color from red, green, blue and alpha values

pub const fn from_rgba(r: f32, g: f32, b: f32, a: f32) -> Color

Create a new color from red, green, blue and alpha values

pub const fn from_rgb(r: f32, g: f32, b: f32) -> Color

Create a new color from red, green and blue values

pub fn from_hex(hex: u32) -> Color

Create a new color from hexadecimal number like 0x000000ff (0xRRGGBBAA)

pub fn from_bytes(r: u8, g: u8, b: u8, a: u8) -> Color

Create a new color from rgba bytes

pub const fn with_red(&self, red: f32) -> Color

Returns the same color with the red passed

pub const fn with_green(&self, green: f32) -> Color

Returns the same color with the green passed

pub const fn with_blue(&self, blue: f32) -> Color

Returns the same color with the blue passed

pub const fn with_alpha(&self, alpha: f32) -> Color

Returns the same color with the alpha passed

pub const fn rgba(&self) -> [f32; 4]

Returns an array with the r, g, b, a values

pub const fn rgb(&self) -> [f32; 3]

Returns an array with the r, g, b values

pub fn hex(&self) -> u32

Returns the hexadecimal representation of the color like 0xRRGGBBAA

pub fn hex_string(&self) -> String

Returns the hexadecimal representantion of the colos as string like #RRGGBBAA

pub fn rgba_u8(&self) -> [u8; 4]

Returns byte representation of the color

pub fn to_premultiplied_alpha(&self) -> Color

Returns the same color as premultiplied alpha