pub struct TextureReader<'a> { /* private fields */ }Implementations
Sourceimpl<'a> TextureReader<'a>
impl<'a> TextureReader<'a>
pub fn new(device: &'a mut Device, texture: &'a Texture) -> TextureReader<'a>
Sourcepub fn with_x_offset(self, offset: u32) -> TextureReader<'a>
pub fn with_x_offset(self, offset: u32) -> TextureReader<'a>
Read pixels from the axis x offset
Sourcepub fn with_y_offset(self, offset: u32) -> TextureReader<'a>
pub fn with_y_offset(self, offset: u32) -> TextureReader<'a>
Read pixels from the axis y offset
Sourcepub fn with_width(self, width: u32) -> TextureReader<'a>
pub fn with_width(self, width: u32) -> TextureReader<'a>
Read pixels until this width from the x offset value
Sourcepub fn with_height(self, height: u32) -> TextureReader<'a>
pub fn with_height(self, height: u32) -> TextureReader<'a>
Read pixels until this height from the y offset value
pub fn read_to(self, bytes: &mut [u8]) -> Result<(), String>