pub struct FrameCache<Value, Computer> { /* private fields */ }Expand description
Caches the results of a computation for one frame. If it is still used next frame, it is not recomputed. If it is not used next frame, it is evicted from the cache to save memory.
Implementations
Sourceimpl<Value, Computer> FrameCache<Value, Computer>
impl<Value, Computer> FrameCache<Value, Computer>
pub fn new(computer: Computer) -> FrameCache<Value, Computer>
Sourcepub fn evict_cache(&mut self)
pub fn evict_cache(&mut self)
Must be called once per frame to clear the cache.
Sourceimpl<Value, Computer> FrameCache<Value, Computer>
impl<Value, Computer> FrameCache<Value, Computer>