pub enum WidgetType {
Show 18 variants
Label,
Link,
TextEdit,
Button,
Checkbox,
RadioButton,
RadioGroup,
SelectableLabel,
ComboBox,
Slider,
DragValue,
ColorButton,
ImageButton,
Image,
CollapsingHeader,
ProgressIndicator,
Window,
Other,
}Expand description
The different types of built-in widgets in egui
Variants
Label
Link
e.g. a hyperlink
TextEdit
Button
Checkbox
RadioButton
RadioGroup
A group of radio buttons.
SelectableLabel
ComboBox
Slider
DragValue
ColorButton
ImageButton
Image
CollapsingHeader
ProgressIndicator
Window
Other
If you cannot fit any of the above slots.
If this is something you think should be added, file an issue.