pub struct ViewportInPixels {
pub left_px: i32,
pub top_px: i32,
pub from_bottom_px: i32,
pub width_px: i32,
pub height_px: i32,
}Expand description
Size of the viewport in whole, physical pixels.
Fields
left_px: i32Physical pixel offset for left side of the viewport.
top_px: i32Physical pixel offset for top side of the viewport.
from_bottom_px: i32Physical pixel offset for bottom side of the viewport.
This is what glViewport, glScissor etc expects for the y axis.
width_px: i32Viewport width in physical pixels.
height_px: i32Viewport height in physical pixels.
Implementations
Sourceimpl ViewportInPixels
impl ViewportInPixels
Sourcepub fn from_points(
rect: &Rect,
pixels_per_point: f32,
screen_size_px: [u32; 2],
) -> ViewportInPixels
pub fn from_points( rect: &Rect, pixels_per_point: f32, screen_size_px: [u32; 2], ) -> ViewportInPixels
Convert from ui points.