CentralPanel

Struct CentralPanel 

pub struct CentralPanel { /* private fields */ }
A panel that covers the remainder of the screen, i.e. whatever area is left after adding other panels.

The order in which you add panels matter! The first panel you add will always be the outermost, and the last you add will always be the innermost.

CentralPanel must be added after all other panels!

NOTE: Any crate::Windows and crate::Areas will cover the top-level CentralPanel.

See the module level docs for more details.

egui::TopBottomPanel::top("my_panel").show(ctx, |ui| {
   ui.label("Hello World! From `TopBottomPanel`, that must be before `CentralPanel`!");
});
egui::CentralPanel::default().show(ctx, |ui| {
   ui.label("Hello World!");
});

Implementations

Source

impl CentralPanel

pub fn frame(self, frame: Frame) -> CentralPanel

Change the background color, margins, etc.

Source

impl CentralPanel

pub fn show_inside<R>( self, ui: &mut Ui, add_contents: impl FnOnce(&mut Ui) -> R, ) -> InnerResponse<R>

Show the panel inside a Ui.

pub fn show<R>( self, ctx: &Context, add_contents: impl FnOnce(&mut Ui) -> R, ) -> InnerResponse<R>

Show the panel at the top level.