pub struct ImageOptions {
pub uv: Rect,
pub bg_fill: Color32,
pub tint: Color32,
pub rotation: Option<(Rot2, Vec2)>,
pub corner_radius: CornerRadius,
}Fields
uv: RectSelect UV range. Default is (0,0) in top-left, (1,1) bottom right.
bg_fill: Color32A solid color to put behind the image. Useful for transparent images.
tint: Color32Multiply image color with this. Default is WHITE (no tint).
rotation: Option<(Rot2, Vec2)>Rotate the image about an origin by some angle
Positive angle is clockwise. Origin is a vector in normalized UV space ((0,0) in top-left, (1,1) bottom right).
To rotate about the center you can pass Vec2::splat(0.5) as the origin.
Due to limitations in the current implementation, this will turn off rounding of the image.
corner_radius: CornerRadiusRound the corners of the image.
The default is no rounding (CornerRadius::ZERO).
Due to limitations in the current implementation, this will turn off any rotation of the image.