Layout

Enum Layout 

pub enum Layout<L>
where L: LineBreaker,
{ SingleLine { line_breaker: L, h_align: HorizontalAlign, v_align: VerticalAlign, }, Wrap { line_breaker: L, h_align: HorizontalAlign, v_align: VerticalAlign, }, }
Built-in GlyphPositioner implementations.

Takes generic LineBreaker to indicate the wrapping style. See BuiltInLineBreaker.

Example

let layout = Layout::default().h_align(HorizontalAlign::Right);

Variants



SingleLine

Renders a single line from left-to-right according to the inner alignment. Hard breaking will end the line, partially hitting the width bound will end the line.

Fields

line_breaker: L


Wrap

Renders multiple lines from left-to-right according to the inner alignment. Hard breaking characters will cause advancement to another line. A characters hitting the width bound will also cause another line to start.

Fields

line_breaker: L

Implementations

Source

impl Layout<BuiltInLineBreaker>

Source

impl<L> Layout<L>
where L: LineBreaker,

pub fn h_align(self, h_align: HorizontalAlign) -> Layout<L>

Returns an identical Layout but with the input h_align

pub fn v_align(self, v_align: VerticalAlign) -> Layout<L>

Returns an identical Layout but with the input v_align

pub fn line_breaker<L2>(self, line_breaker: L2) -> Layout<L2>
where L2: LineBreaker,

Returns an identical Layout but with the input line_breaker