TextureBuilder

Struct TextureBuilder 

pub struct TextureBuilder<'a, 'b> { /* private fields */ }

Implementations

Source

impl<'a, 'b> TextureBuilder<'a, 'b>

pub fn new(device: &'a mut Device) -> TextureBuilder<'a, 'b>

pub fn from_source<S>(self, source: S) -> TextureBuilder<'a, 'b>
where S: TextureSource + 'static,

Creates a texture from source’s raw type Check TextureSource

pub fn from_image(self, bytes: &'b [u8]) -> TextureBuilder<'a, 'b>

Creates a Texture from an image

pub fn from_bytes( self, bytes: &'b [u8], width: u32, height: u32, ) -> TextureBuilder<'a, 'b>

Creates a Texture from a buffer of pixels

pub fn from_empty_buffer( self, width: u32, height: u32, ) -> TextureBuilder<'a, 'b>

Creates a buffer for the size passed in and creates a Texture with it

pub fn with_size(self, width: u32, height: u32) -> TextureBuilder<'a, 'b>

Set the size of the texture (ignored if used with from_image, image size will be used instead)

pub fn with_depth(self) -> TextureBuilder<'a, 'b>

Enable depth

pub fn with_format(self, format: TextureFormat) -> TextureBuilder<'a, 'b>

Set the Texture format (ignored if used with from_image, Rgba will be used instead )

pub fn with_filter( self, min: TextureFilter, mag: TextureFilter, ) -> TextureBuilder<'a, 'b>

Set the Texture filter modes

pub fn with_wrap(self, x: TextureWrap, y: TextureWrap) -> TextureBuilder<'a, 'b>

Set the texture wrap modes (x -> s, y -> t)

pub fn with_premultiplied_alpha(self) -> TextureBuilder<'a, 'b>

Process the texels to multiply the rgb values by the alpha

pub fn with_mipmaps(self, enable: bool) -> TextureBuilder<'a, 'b>

Toggle mipmap generation (with Linear filter if enabled)

pub fn with_mipmap_filter(self, filter: TextureFilter) -> TextureBuilder<'a, 'b>

Set mipmap filtering function

pub fn build(self) -> Result<Texture, String>