pub struct Keyboard {
pub pressed: HashSet<KeyCode>,
pub down: HashMap<KeyCode, f32>,
pub released: HashSet<KeyCode>,
pub last_key_released: Option<KeyCode>,
}Expand description
Represent the keyboard data
Fields
pressed: HashSet<KeyCode>pressed keys
down: HashMap<KeyCode, f32>down keys
released: HashSet<KeyCode>released keys
last_key_released: Option<KeyCode>last key release
Implementations
Sourceimpl Keyboard
impl Keyboard
Sourcepub fn last_key_released(&self) -> Option<KeyCode>
pub fn last_key_released(&self) -> Option<KeyCode>
returns the last key released
Sourcepub fn was_released(&self, key: KeyCode) -> bool
pub fn was_released(&self, key: KeyCode) -> bool
returns true if the key was released on the last frame
Sourcepub fn down_delta(&self, key: KeyCode) -> f32
pub fn down_delta(&self, key: KeyCode) -> f32
returns the total time that this key is down
Sourcepub fn was_pressed(&self, key: KeyCode) -> bool
pub fn was_pressed(&self, key: KeyCode) -> bool
returns true if the key was pressed on the last frame