IVec4

Struct IVec4 

#[repr(C)]
pub struct IVec4 { pub x: i32, pub y: i32, pub z: i32, pub w: i32, }
A 4-dimensional vector.

Fields

x: i32y: i32z: i32w: i32

Implementations

Source

impl IVec4

pub const ZERO: IVec4

All zeroes.

pub const ONE: IVec4

All ones.

pub const NEG_ONE: IVec4

All negative ones.

pub const MIN: IVec4

All i32::MIN.

pub const MAX: IVec4

All i32::MAX.

pub const X: IVec4

A unit vector pointing along the positive X axis.

pub const Y: IVec4

A unit vector pointing along the positive Y axis.

pub const Z: IVec4

A unit vector pointing along the positive Z axis.

pub const W: IVec4

A unit vector pointing along the positive W axis.

pub const NEG_X: IVec4

A unit vector pointing along the negative X axis.

pub const NEG_Y: IVec4

A unit vector pointing along the negative Y axis.

pub const NEG_Z: IVec4

A unit vector pointing along the negative Z axis.

pub const NEG_W: IVec4

A unit vector pointing along the negative W axis.

pub const AXES: [IVec4; 4]

The unit axes.

pub const fn new(x: i32, y: i32, z: i32, w: i32) -> IVec4

Creates a new vector.

pub const fn splat(v: i32) -> IVec4

Creates a vector with all elements set to v.

pub fn map<F>(self, f: F) -> IVec4
where F: Fn(i32) -> i32,

Returns a vector containing each element of self modified by a mapping function f.

pub fn select(mask: BVec4, if_true: IVec4, if_false: IVec4) -> IVec4

Creates a vector from the elements in if_true and if_false, selecting which to use for each element of self.

A true element in the mask uses the corresponding element from if_true, and false uses the element from if_false.

pub const fn from_array(a: [i32; 4]) -> IVec4

Creates a new vector from an array.

pub const fn to_array(&self) -> [i32; 4]

[x, y, z, w]

pub const fn from_slice(slice: &[i32]) -> IVec4

Creates a vector from the first 4 values in slice.

Panics

Panics if slice is less than 4 elements long.

pub fn write_to_slice(self, slice: &mut [i32])

Writes the elements of self to the first 4 elements in slice.

Panics

Panics if slice is less than 4 elements long.

pub fn truncate(self) -> IVec3

Creates a 3D vector from the x, y and z elements of self, discarding w.

Truncation to IVec3 may also be performed by using self.xyz().

pub fn with_x(self, x: i32) -> IVec4

Creates a 4D vector from self with the given value of x.

pub fn with_y(self, y: i32) -> IVec4

Creates a 4D vector from self with the given value of y.

pub fn with_z(self, z: i32) -> IVec4

Creates a 4D vector from self with the given value of z.

pub fn with_w(self, w: i32) -> IVec4

Creates a 4D vector from self with the given value of w.

pub fn dot(self, rhs: IVec4) -> i32

Computes the dot product of self and rhs.

pub fn dot_into_vec(self, rhs: IVec4) -> IVec4

Returns a vector where every component is the dot product of self and rhs.

pub fn min(self, rhs: IVec4) -> IVec4

Returns a vector containing the minimum values for each element of self and rhs.

In other words this computes [self.x.min(rhs.x), self.y.min(rhs.y), ..].

pub fn max(self, rhs: IVec4) -> IVec4

Returns a vector containing the maximum values for each element of self and rhs.

In other words this computes [self.x.max(rhs.x), self.y.max(rhs.y), ..].

pub fn clamp(self, min: IVec4, max: IVec4) -> IVec4

Component-wise clamping of values, similar to i32::clamp.

Each element in min must be less-or-equal to the corresponding element in max.

Panics

Will panic if min is greater than max when glam_assert is enabled.

pub fn min_element(self) -> i32

Returns the horizontal minimum of self.

In other words this computes min(x, y, ..).

pub fn max_element(self) -> i32

Returns the horizontal maximum of self.

In other words this computes max(x, y, ..).

pub fn element_sum(self) -> i32

Returns the sum of all elements of self.

In other words, this computes self.x + self.y + ...

pub fn element_product(self) -> i32

Returns the product of all elements of self.

In other words, this computes self.x * self.y * ...

pub fn cmpeq(self, rhs: IVec4) -> BVec4

Returns a vector mask containing the result of a == comparison for each element of self and rhs.

In other words, this computes [self.x == rhs.x, self.y == rhs.y, ..] for all elements.

pub fn cmpne(self, rhs: IVec4) -> BVec4

Returns a vector mask containing the result of a != comparison for each element of self and rhs.

In other words this computes [self.x != rhs.x, self.y != rhs.y, ..] for all elements.

pub fn cmpge(self, rhs: IVec4) -> BVec4

Returns a vector mask containing the result of a >= comparison for each element of self and rhs.

In other words this computes [self.x >= rhs.x, self.y >= rhs.y, ..] for all elements.

pub fn cmpgt(self, rhs: IVec4) -> BVec4

Returns a vector mask containing the result of a > comparison for each element of self and rhs.

In other words this computes [self.x > rhs.x, self.y > rhs.y, ..] for all elements.

pub fn cmple(self, rhs: IVec4) -> BVec4

Returns a vector mask containing the result of a <= comparison for each element of self and rhs.

In other words this computes [self.x <= rhs.x, self.y <= rhs.y, ..] for all elements.

pub fn cmplt(self, rhs: IVec4) -> BVec4

Returns a vector mask containing the result of a < comparison for each element of self and rhs.

In other words this computes [self.x < rhs.x, self.y < rhs.y, ..] for all elements.

pub fn abs(self) -> IVec4

Returns a vector containing the absolute value of each element of self.

pub fn signum(self) -> IVec4

Returns a vector with elements representing the sign of self.

  • 0 if the number is zero
  • 1 if the number is positive
  • -1 if the number is negative
pub fn is_negative_bitmask(self) -> u32

Returns a bitmask with the lowest 4 bits set to the sign bits from the elements of self.

A negative element results in a 1 bit and a positive element in a 0 bit. Element x goes into the first lowest bit, element y into the second, etc.

pub fn length_squared(self) -> i32

Computes the squared length of self.

pub fn distance_squared(self, rhs: IVec4) -> i32

Compute the squared euclidean distance between two points in space.

pub fn div_euclid(self, rhs: IVec4) -> IVec4

Returns the element-wise quotient of [Euclidean division] of self by rhs.

Panics

This function will panic if any rhs element is 0 or the division results in overflow.

pub fn rem_euclid(self, rhs: IVec4) -> IVec4

Returns the element-wise remainder of Euclidean division of self by rhs.

Panics

This function will panic if any rhs element is 0 or the division results in overflow.

pub fn as_vec4(&self) -> Vec4

Casts all elements of self to f32.

pub fn as_dvec4(&self) -> DVec4

Casts all elements of self to f64.

pub fn as_i8vec4(&self) -> I8Vec4

Casts all elements of self to i8.

pub fn as_u8vec4(&self) -> U8Vec4

Casts all elements of self to u8.

pub fn as_i16vec4(&self) -> I16Vec4

Casts all elements of self to i16.

pub fn as_u16vec4(&self) -> U16Vec4

Casts all elements of self to u16.

pub fn as_uvec4(&self) -> UVec4

Casts all elements of self to u32.

pub fn as_i64vec4(&self) -> I64Vec4

Casts all elements of self to i64.

pub fn as_u64vec4(&self) -> U64Vec4

Casts all elements of self to u64.

pub const fn wrapping_add(self, rhs: IVec4) -> IVec4

Returns a vector containing the wrapping addition of self and rhs.

In other words this computes [self.x.wrapping_add(rhs.x), self.y.wrapping_add(rhs.y), ..].

pub const fn wrapping_sub(self, rhs: IVec4) -> IVec4

Returns a vector containing the wrapping subtraction of self and rhs.

In other words this computes [self.x.wrapping_sub(rhs.x), self.y.wrapping_sub(rhs.y), ..].

pub const fn wrapping_mul(self, rhs: IVec4) -> IVec4

Returns a vector containing the wrapping multiplication of self and rhs.

In other words this computes [self.x.wrapping_mul(rhs.x), self.y.wrapping_mul(rhs.y), ..].

pub const fn wrapping_div(self, rhs: IVec4) -> IVec4

Returns a vector containing the wrapping division of self and rhs.

In other words this computes [self.x.wrapping_div(rhs.x), self.y.wrapping_div(rhs.y), ..].

pub const fn saturating_add(self, rhs: IVec4) -> IVec4

Returns a vector containing the saturating addition of self and rhs.

In other words this computes [self.x.saturating_add(rhs.x), self.y.saturating_add(rhs.y), ..].

pub const fn saturating_sub(self, rhs: IVec4) -> IVec4

Returns a vector containing the saturating subtraction of self and rhs.

In other words this computes [self.x.saturating_sub(rhs.x), self.y.saturating_sub(rhs.y), ..].

pub const fn saturating_mul(self, rhs: IVec4) -> IVec4

Returns a vector containing the saturating multiplication of self and rhs.

In other words this computes [self.x.saturating_mul(rhs.x), self.y.saturating_mul(rhs.y), ..].

pub const fn saturating_div(self, rhs: IVec4) -> IVec4

Returns a vector containing the saturating division of self and rhs.

In other words this computes [self.x.saturating_div(rhs.x), self.y.saturating_div(rhs.y), ..].

pub const fn wrapping_add_unsigned(self, rhs: UVec4) -> IVec4

Returns a vector containing the wrapping addition of self and unsigned vector rhs.

In other words this computes [self.x.wrapping_add_unsigned(rhs.x), self.y.wrapping_add_unsigned(rhs.y), ..].

pub const fn wrapping_sub_unsigned(self, rhs: UVec4) -> IVec4

Returns a vector containing the wrapping subtraction of self and unsigned vector rhs.

In other words this computes [self.x.wrapping_sub_unsigned(rhs.x), self.y.wrapping_sub_unsigned(rhs.y), ..].

pub const fn saturating_add_unsigned(self, rhs: UVec4) -> IVec4

In other words this computes [self.x.saturating_add_unsigned(rhs.x), self.y.saturating_add_unsigned(rhs.y), ..].

pub const fn saturating_sub_unsigned(self, rhs: UVec4) -> IVec4

Returns a vector containing the saturating subtraction of self and unsigned vector rhs.

In other words this computes [self.x.saturating_sub_unsigned(rhs.x), self.y.saturating_sub_unsigned(rhs.y), ..].