pub struct Color {
pub r: f32,
pub g: f32,
pub b: f32,
pub a: f32,
}Expand description
Represents a visual color
Fields
r: f32Red value
g: f32Green value
b: f32Blue value
a: f32Alpha value
Implementations
Sourceimpl Color
impl Color
pub const TRANSPARENT: Color
pub const WHITE: Color
pub const BLACK: Color
pub const RED: Color
pub const GREEN: Color
pub const BLUE: Color
pub const YELLOW: Color
pub const MAGENTA: Color
pub const SILVER: Color
pub const GRAY: Color
pub const OLIVE: Color
pub const PURPLE: Color
pub const MAROON: Color
pub const BROWN: Color
pub const SADDLE_BROWN: Color
pub const AQUA: Color
pub const TEAL: Color
pub const NAVY: Color
pub const ORANGE: Color
pub const PINK: Color
Sourcepub const fn new(r: f32, g: f32, b: f32, a: f32) -> Color
pub const fn new(r: f32, g: f32, b: f32, a: f32) -> Color
Create a new color from red, green, blue and alpha values
Sourcepub const fn from_rgba(r: f32, g: f32, b: f32, a: f32) -> Color
pub const fn from_rgba(r: f32, g: f32, b: f32, a: f32) -> Color
Create a new color from red, green, blue and alpha values
Sourcepub const fn from_rgb(r: f32, g: f32, b: f32) -> Color
pub const fn from_rgb(r: f32, g: f32, b: f32) -> Color
Create a new color from red, green and blue values
Sourcepub fn from_hex(hex: u32) -> Color
pub fn from_hex(hex: u32) -> Color
Create a new color from hexadecimal number like 0x000000ff (0xRRGGBBAA)
Sourcepub const fn with_green(&self, green: f32) -> Color
pub const fn with_green(&self, green: f32) -> Color
Returns the same color with the green passed
Sourcepub const fn with_alpha(&self, alpha: f32) -> Color
pub const fn with_alpha(&self, alpha: f32) -> Color
Returns the same color with the alpha passed
Sourcepub fn hex_string(&self) -> String
pub fn hex_string(&self) -> String
Returns the hexadecimal representantion of the colos as string like #RRGGBBAA
Sourcepub fn to_premultiplied_alpha(&self) -> Color
pub fn to_premultiplied_alpha(&self) -> Color
Returns the same color as premultiplied alpha