pub struct Label { /* private fields */ }Expand description
Static text.
Usually it is more convenient to use Ui::label.
ui.label("Equivalent");
ui.add(egui::Label::new("Equivalent"));
ui.add(egui::Label::new("With Options").truncate());
ui.label(egui::RichText::new("With formatting").underline());For full control of the text you can use crate::text::LayoutJob
as argument to Self::new.
Implementations
Sourceimpl Label
impl Label
pub fn new(text: impl Into<WidgetText>) -> Label
pub fn text(&self) -> &str
Sourcepub fn wrap_mode(self, wrap_mode: TextWrapMode) -> Label
pub fn wrap_mode(self, wrap_mode: TextWrapMode) -> Label
Set the wrap mode for the text.
By default, crate::Ui::wrap_mode will be used, which can be overridden with crate::Style::wrap_mode.
Note that any \n in the text will always produce a new line.
Sourcepub fn wrap(self) -> Label
pub fn wrap(self) -> Label
Set Self::wrap_mode to TextWrapMode::Wrap.
Sourcepub fn extend(self) -> Label
pub fn extend(self) -> Label
Set Self::wrap_mode to TextWrapMode::Extend,
disabling wrapping and truncating, and instead expanding the parent Ui.
Sourcepub fn halign(self, align: Align) -> Label
pub fn halign(self, align: Align) -> Label
Sets the horizontal alignment of the Label to the given Align value.
Sourcepub fn selectable(self, selectable: bool) -> Label
pub fn selectable(self, selectable: bool) -> Label
Can the user select the text with the mouse?
Overrides crate::style::Interaction::selectable_labels.
Sourcepub fn sense(self, sense: Sense) -> Label
pub fn sense(self, sense: Sense) -> Label
Make the label respond to clicks and/or drags.
By default, a label is inert and does not respond to click or drags. By calling this you can turn the label into a button of sorts. This will also give the label the hover-effect of a button, but without the frame.
if ui.add(Label::new("click me").sense(Sense::click())).clicked() {
/* … */
}Trait Implementations