pub struct TextureBuilder<'a, 'b> { /* private fields */ }Implementations
Sourceimpl<'a, 'b> TextureBuilder<'a, 'b>
impl<'a, 'b> TextureBuilder<'a, 'b>
pub fn new(device: &'a mut Device) -> TextureBuilder<'a, 'b>
Sourcepub fn from_source<S>(self, source: S) -> TextureBuilder<'a, 'b>where
S: TextureSource + 'static,
pub fn from_source<S>(self, source: S) -> TextureBuilder<'a, 'b>where
S: TextureSource + 'static,
Creates a texture from source’s raw type Check TextureSource
Sourcepub fn from_image(self, bytes: &'b [u8]) -> TextureBuilder<'a, 'b>
pub fn from_image(self, bytes: &'b [u8]) -> TextureBuilder<'a, 'b>
Creates a Texture from an image
Sourcepub fn from_bytes(
self,
bytes: &'b [u8],
width: u32,
height: u32,
) -> TextureBuilder<'a, 'b>
pub fn from_bytes( self, bytes: &'b [u8], width: u32, height: u32, ) -> TextureBuilder<'a, 'b>
Creates a Texture from a buffer of pixels
Sourcepub fn from_empty_buffer(
self,
width: u32,
height: u32,
) -> TextureBuilder<'a, 'b>
pub fn from_empty_buffer( self, width: u32, height: u32, ) -> TextureBuilder<'a, 'b>
Creates a buffer for the size passed in and creates a Texture with it
Sourcepub fn with_size(self, width: u32, height: u32) -> TextureBuilder<'a, 'b>
pub fn with_size(self, width: u32, height: u32) -> TextureBuilder<'a, 'b>
Set the size of the texture (ignored if used with from_image, image size will be used instead)
Sourcepub fn with_depth(self) -> TextureBuilder<'a, 'b>
pub fn with_depth(self) -> TextureBuilder<'a, 'b>
Enable depth
Sourcepub fn with_format(self, format: TextureFormat) -> TextureBuilder<'a, 'b>
pub fn with_format(self, format: TextureFormat) -> TextureBuilder<'a, 'b>
Set the Texture format (ignored if used with from_image, Rgba will be used instead )
Sourcepub fn with_filter(
self,
min: TextureFilter,
mag: TextureFilter,
) -> TextureBuilder<'a, 'b>
pub fn with_filter( self, min: TextureFilter, mag: TextureFilter, ) -> TextureBuilder<'a, 'b>
Set the Texture filter modes
Sourcepub fn with_wrap(self, x: TextureWrap, y: TextureWrap) -> TextureBuilder<'a, 'b>
pub fn with_wrap(self, x: TextureWrap, y: TextureWrap) -> TextureBuilder<'a, 'b>
Set the texture wrap modes (x -> s, y -> t)
Sourcepub fn with_premultiplied_alpha(self) -> TextureBuilder<'a, 'b>
pub fn with_premultiplied_alpha(self) -> TextureBuilder<'a, 'b>
Process the texels to multiply the rgb values by the alpha
Sourcepub fn with_mipmaps(self, enable: bool) -> TextureBuilder<'a, 'b>
pub fn with_mipmaps(self, enable: bool) -> TextureBuilder<'a, 'b>
Toggle mipmap generation (with Linear filter if enabled)
Sourcepub fn with_mipmap_filter(self, filter: TextureFilter) -> TextureBuilder<'a, 'b>
pub fn with_mipmap_filter(self, filter: TextureFilter) -> TextureBuilder<'a, 'b>
Set mipmap filtering function
pub fn build(self) -> Result<Texture, String>