pub struct Random { /* private fields */ }Expand description
Wrapper around a random generator based on Pcg32.
Implementations
Methods from Deref<Target = Lcg64Xsh32>
Sourcepub fn advance(&mut self, delta: u64)
pub fn advance(&mut self, delta: u64)
Multi-step advance functions (jump-ahead, jump-back)
The method used here is based on Brown, “Random Number Generation with Arbitrary Stride,”, Transactions of the American Nuclear Society (Nov. 1994). The algorithm is very similar to fast exponentiation.
Even though delta is an unsigned integer, we can pass a signed integer to go backwards, it just goes “the long way round”.
Using this function is equivalent to calling next_32() delta
number of times.